==> frock-1.1.1.tgz: package/lib/register-db.js <==
'use strict';

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var path = require('path');

var bole = require('bole');

var _require2 = require('mkdirp');

var mkdirp = _require2.sync;

var _require3 = require('resolve');

var resolve = _require3.sync;

var log = bole('frock/register-db');

module.exports = createDbRegister;

function createDbRegister(pwd, _path) {
  var _require = arguments.length <= 2 || arguments[2] === undefined ? require : arguments[2];

  var level = loadCompatibleDb();
  var dbs = new Map();

  var dbPath = _path;

  dbs.register = register;
  dbs._updatePath = updatePath;

  return dbs;

  function register(name) {
    if (!level) {
      throw new Error('A handler requested a database, but you don\'t have a local database\n' + 'installed; please see the documentation for further information.');
    } else if (!dbPath) {
      throw new Error('A handler requested a database, but a database path wasn\'t specified.');
    }

    if (dbs.has(name)) {
      return dbs.get(name);
    }

    var db = level(path.resolve(dbPath, name), { valueEncoding: 'json' });

    dbs.set(name, db);

    log.debug('registered db ' + name);

    return db;
  }

  function updatePath(_path) {
    var newPath = path.resolve(pwd, _path);

    // don't update if identical
    if (newPath === dbPath) {
      return;
    }

    log.debug('updating db path to ' + newPath);

    // make our db directory, ok to throw
    mkdirp(newPath);
    dbPath = newPath;

    // clear our saved dbs if we're changing paths
    dbs.clear();
  }

  function loadCompatibleDb() {
    var compatibleDbPkgs = ['level', 'levelup'];

    for (var i = 0; i < compatibleDbPkgs.length; ++i) {
      var db = tryRequire(compatibleDbPkgs[i]);

      if (db) {
        return db;
      }
    }
  }

  function tryRequire(pkg) {
    var required = undefined;

    try {
      required = _require(resolve(pkg, { basedir: pwd }));
    } catch (e) {
      // pass
    }

    return required;
  }
}

==> frock-3.0.0.tgz: package/lib/register-db.js <==
'use strict';

/**
 * Copyright 2015 Urban Airship Inc. and Contributors. Subject to the LICENSE
 * file at the top-level directory of this distribution and at
 * https://github.com/urbanairship/frock/blob/master/LICENSE
 */
var path = require('path');

var bole = require('bole');

var _require2 = require('mkdirp'),
    mkdirp = _require2.sync;

var _require3 = require('resolve'),
    resolve = _require3.sync;

var log = bole('frock/register-db');

module.exports = createDbRegister;

function createDbRegister(pwd, _path) {
  var _require = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : require;

  var level = loadCompatibleDb();
  var dbs = new Map();

  var dbPath = _path;

  dbs.register = register;
  dbs._updatePath = updatePath;

  return dbs;

  function register(name) {
    if (!level) {
      throw new Error('A handler requested a database, but you don\'t have a local database\n' + 'installed; please see the documentation for further information.');
    } else if (!dbPath) {
      throw new Error('A handler requested a database, but a database path wasn\'t specified.');
    }

    if (dbs.has(name)) {
      return dbs.get(name);
    }

    var db = level(path.resolve(dbPath, name), { valueEncoding: 'json' });

    dbs.set(name, db);

    log.debug('registered db ' + name);

    return db;
  }

  function updatePath(_path) {
    var newPath = path.resolve(pwd, _path);

    // don't update if identical
    if (newPath === dbPath) {
      return;
    }

    log.debug('updating db path to ' + newPath);

    // make our db directory, ok to throw
    mkdirp(newPath);
    dbPath = newPath;

    // clear our saved dbs if we're changing paths
    dbs.clear();
  }

  function loadCompatibleDb() {
    var compatibleDbPkgs = ['level', 'levelup'];

    for (var i = 0; i < compatibleDbPkgs.length; ++i) {
      var db = tryRequire(compatibleDbPkgs[i]);

      if (db) {
        return db;
      }
    }
  }

  function tryRequire(pkg) {
    var required = void 0;

    try {
      required = _require(resolve(pkg, { basedir: pwd }));
    } catch (e) {
      // pass
    }

    return required;
  }
}
